// $Id: MachineConfig.cc 6749 2007-07-28 10:55:59Z m9710797 $

#include "MachineConfig.hh"
#include "XMLElement.hh"

namespace openmsx {

MachineConfig::MachineConfig(MSXMotherBoard& motherBoard,
                             const std::string& machineName)
	: HardwareConfig(motherBoard, machineName)
{
	load("machines");
}

const XMLElement& MachineConfig::getDevices() const
{
	return getConfig().getChild("devices");
}

} // namespace openmsx
